==> xmpp-extensions-0.5.1-sources.jar: rocks/xmpp/extensions/muc/model/Item.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.muc.model;

import rocks.xmpp.core.Jid;

/**
 * The {@code <item/>} element, which is used in both #admin and #user namespace to manage members and indicate users in a chat room.
 *
 * @author Christian Schudt
 */
public interface Item {
    /**
     * Gets the nick name.
     *
     * @return The nick name.
     */
    String getNick();

    /**
     * Gets the role.
     *
     * @return The role.
     */
    Role getRole();

    /**
     * Gets the JID.
     *
     * @return The JID.
     */
    Jid getJid();

    /**
     * Gets the affiliation.
     *
     * @return The affiliation.
     */
    Affiliation getAffiliation();

    /**
     * Gets the reason for a kick or ban.
     *
     * @return The reason.
     */
    String getReason();

    /**
     * Gets the actor for a kick or ban.
     *
     * @return The actor.
     */
    Actor getActor();
}

==> xmpp-extensions-0.6.0-sources.jar: rocks/xmpp/extensions/muc/model/Item.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2015 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.extensions.muc.model;

import rocks.xmpp.addr.Jid;

/**
 * The {@code <item/>} element, which is used in both <code>#admin</code> and <code>#user</code> namespace to manage members and indicate users in a chat room.
 *
 * @author Christian Schudt
 */
public interface Item {
    /**
     * Gets the nick name.
     *
     * @return The nick name.
     */
    String getNick();

    /**
     * Gets the role.
     *
     * @return The role.
     */
    Role getRole();

    /**
     * Gets the JID.
     *
     * @return The JID.
     */
    Jid getJid();

    /**
     * Gets the affiliation.
     *
     * @return The affiliation.
     */
    Affiliation getAffiliation();

    /**
     * Gets the reason for a kick or ban.
     *
     * @return The reason.
     */
    String getReason();

    /**
     * Gets the actor for a kick or ban.
     *
     * @return The actor.
     */
    Actor getActor();
}
